==> webknossos-0.10.24.tar.gz: webknossos-0.10.24/webknossos/client/_generated/models/__init__.py <==
""" Contains all the data models used in inputs/outputs """

from .action import Action
from .action_annotation_layer_parameters import ActionAnnotationLayerParameters
from .action_annotation_private_link_params import ActionAnnotationPrivateLinkParams
from .action_any_content import ActionAnyContent
from .action_cancel_upload_information import ActionCancelUploadInformation
from .action_js_value import ActionJsValue
from .action_multipart_form_data_temporary_file import (
    ActionMultipartFormDataTemporaryFile,
)
from .action_reserve_upload_information import ActionReserveUploadInformation
from .action_upload_information import ActionUploadInformation
from .annotation_info_response_200 import AnnotationInfoResponse200
from .annotation_info_response_200_annotation_layers_item import (
    AnnotationInfoResponse200AnnotationLayersItem,
)
from .annotation_info_response_200_data_store import AnnotationInfoResponse200DataStore
from .annotation_info_response_200_owner import AnnotationInfoResponse200Owner
from .annotation_info_response_200_owner_teams_item import (
    AnnotationInfoResponse200OwnerTeamsItem,
)
from .annotation_info_response_200_restrictions import (
    AnnotationInfoResponse200Restrictions,
)
from .annotation_info_response_200_settings import AnnotationInfoResponse200Settings
from .annotation_info_response_200_settings_resolution_restrictions import (
    AnnotationInfoResponse200SettingsResolutionRestrictions,
)
from .annotation_info_response_200_stats import AnnotationInfoResponse200Stats
from .annotation_info_response_200_task import AnnotationInfoResponse200Task
from .annotation_info_response_200_task_needed_experience import (
    AnnotationInfoResponse200TaskNeededExperience,
)
from .annotation_info_response_200_task_status import (
    AnnotationInfoResponse200TaskStatus,
)
from .annotation_info_response_200_task_type import AnnotationInfoResponse200TaskType
from .annotation_info_response_200_task_type_settings import (
    AnnotationInfoResponse200TaskTypeSettings,
)
from .annotation_info_response_200_task_type_settings_resolution_restrictions import (
    AnnotationInfoResponse200TaskTypeSettingsResolutionRestrictions,
)
from .annotation_info_response_200_tracing_store import (
    AnnotationInfoResponse200TracingStore,
)
from .annotation_info_response_200_user import AnnotationInfoResponse200User
from .annotation_info_response_200_user_teams_item import (
    AnnotationInfoResponse200UserTeamsItem,
)
from .annotation_infos_by_task_id_response_200_item import (
    AnnotationInfosByTaskIdResponse200Item,
)
from .annotation_infos_by_task_id_response_200_item_annotation_layers_item import (
    AnnotationInfosByTaskIdResponse200ItemAnnotationLayersItem,
)
from .annotation_infos_by_task_id_response_200_item_data_store import (
    AnnotationInfosByTaskIdResponse200ItemDataStore,
)
from .annotation_infos_by_task_id_response_200_item_owner import (
    AnnotationInfosByTaskIdResponse200ItemOwner,
)
from .annotation_infos_by_task_id_response_200_item_owner_teams_item import (
    AnnotationInfosByTaskIdResponse200ItemOwnerTeamsItem,
)
from .annotation_infos_by_task_id_response_200_item_restrictions import (
    AnnotationInfosByTaskIdResponse200ItemRestrictions,
)
from .annotation_infos_by_task_id_response_200_item_settings import (
    AnnotationInfosByTaskIdResponse200ItemSettings,
)
from .annotation_infos_by_task_id_response_200_item_settings_resolution_restrictions import (
    AnnotationInfosByTaskIdResponse200ItemSettingsResolutionRestrictions,
)
from .annotation_infos_by_task_id_response_200_item_stats import (
    AnnotationInfosByTaskIdResponse200ItemStats,
)
from .annotation_infos_by_task_id_response_200_item_task import (
    AnnotationInfosByTaskIdResponse200ItemTask,
)
from .annotation_infos_by_task_id_response_200_item_task_needed_experience import (
    AnnotationInfosByTaskIdResponse200ItemTaskNeededExperience,
)
from .annotation_infos_by_task_id_response_200_item_task_status import (
    AnnotationInfosByTaskIdResponse200ItemTaskStatus,
)
from .annotation_infos_by_task_id_response_200_item_task_type import (
    AnnotationInfosByTaskIdResponse200ItemTaskType,
)
from .annotation_infos_by_task_id_response_200_item_task_type_settings import (
    AnnotationInfosByTaskIdResponse200ItemTaskTypeSettings,
)
from .annotation_infos_by_task_id_response_200_item_task_type_settings_resolution_restrictions import (
    AnnotationInfosByTaskIdResponse200ItemTaskTypeSettingsResolutionRestrictions,
)
from .annotation_infos_by_task_id_response_200_item_tracing_store import (
    AnnotationInfosByTaskIdResponse200ItemTracingStore,
)
from .annotation_infos_by_task_id_response_200_item_user import (
    AnnotationInfosByTaskIdResponse200ItemUser,
)
from .annotation_infos_by_task_id_response_200_item_user_teams_item import (
    AnnotationInfosByTaskIdResponse200ItemUserTeamsItem,
)
from .build_info_response_200 import BuildInfoResponse200
from .build_info_response_200_webknossos import BuildInfoResponse200Webknossos
from .build_info_response_200_webknossos_wrap import BuildInfoResponse200WebknossosWrap
from .create_private_link_json_body import CreatePrivateLinkJsonBody
from .create_project_json_body import CreateProjectJsonBody
from .current_user_info_response_200 import CurrentUserInfoResponse200
from .current_user_info_response_200_experiences import (
    CurrentUserInfoResponse200Experiences,
)
from .current_user_info_response_200_novel_user_experience_infos import (
    CurrentUserInfoResponse200NovelUserExperienceInfos,
)
from .current_user_info_response_200_teams_item import (
    CurrentUserInfoResponse200TeamsItem,
)
from .dataset_cancel_upload_json_body import DatasetCancelUploadJsonBody
from .dataset_finish_upload_json_body import DatasetFinishUploadJsonBody
from .dataset_info_response_200 import DatasetInfoResponse200
from .dataset_info_response_200_allowed_teams_item import (
    DatasetInfoResponse200AllowedTeamsItem,
)
from .dataset_info_response_200_data_source import DatasetInfoResponse200DataSource
from .dataset_info_response_200_data_source_data_layers_item import (
    DatasetInfoResponse200DataSourceDataLayersItem,
)
from .dataset_info_response_200_data_source_data_layers_item_bounding_box import (
    DatasetInfoResponse200DataSourceDataLayersItemBoundingBox,
)
from .dataset_info_response_200_data_source_data_layers_item_default_view_configuration import (
    DatasetInfoResponse200DataSourceDataLayersItemDefaultViewConfiguration,
)
from .dataset_info_response_200_data_source_id import DatasetInfoResponse200DataSourceId
from .dataset_info_response_200_data_store import DatasetInfoResponse200DataStore
from .dataset_list_response_200_item import DatasetListResponse200Item
from .dataset_list_response_200_item_allowed_teams_item import (
    DatasetListResponse200ItemAllowedTeamsItem,
)
from .dataset_list_response_200_item_data_source import (
    DatasetListResponse200ItemDataSource,
)
from .dataset_list_response_200_item_data_source_id import (
    DatasetListResponse200ItemDataSourceId,
)
from .dataset_list_response_200_item_data_store import (
    DatasetListResponse200ItemDataStore,
)
from .dataset_reserve_upload_json_body import DatasetReserveUploadJsonBody
from .dataset_sharing_token_response_200 import DatasetSharingTokenResponse200
from .dataset_update_json_body import DatasetUpdateJsonBody
from .datastore_list_response_200_item import DatastoreListResponse200Item
from .generate_token_for_data_store_response_200 import (
    GenerateTokenForDataStoreResponse200,
)
from .project_info_by_id_response_200 import ProjectInfoByIdResponse200
from .project_info_by_id_response_200_owner import ProjectInfoByIdResponse200Owner
from .project_info_by_id_response_200_owner_teams_item import (
    ProjectInfoByIdResponse200OwnerTeamsItem,
)
from .project_info_by_name_response_200 import ProjectInfoByNameResponse200
from .project_info_by_name_response_200_owner import ProjectInfoByNameResponse200Owner
from .project_info_by_name_response_200_owner_teams_item import (
    ProjectInfoByNameResponse200OwnerTeamsItem,
)
from .task_create_from_files_json_body import TaskCreateFromFilesJsonBody
from .task_info_response_200 import TaskInfoResponse200
from .task_info_response_200_needed_experience import (
    TaskInfoResponse200NeededExperience,
)
from .task_info_response_200_status import TaskInfoResponse200Status
from .task_info_response_200_type import TaskInfoResponse200Type
from .task_info_response_200_type_settings import TaskInfoResponse200TypeSettings
from .task_info_response_200_type_settings_resolution_restrictions import (
    TaskInfoResponse200TypeSettingsResolutionRestrictions,
)
from .task_infos_by_project_id_response_200_item import (
    TaskInfosByProjectIdResponse200Item,
)
from .task_infos_by_project_id_response_200_item_needed_experience import (
    TaskInfosByProjectIdResponse200ItemNeededExperience,
)
from .task_infos_by_project_id_response_200_item_status import (
    TaskInfosByProjectIdResponse200ItemStatus,
)
from .task_infos_by_project_id_response_200_item_type import (
    TaskInfosByProjectIdResponse200ItemType,
)
from .task_infos_by_project_id_response_200_item_type_settings import (
    TaskInfosByProjectIdResponse200ItemTypeSettings,
)
from .task_infos_by_project_id_response_200_item_type_settings_resolution_restrictions import (
    TaskInfosByProjectIdResponse200ItemTypeSettingsResolutionRestrictions,
)
from .team_list_response_200_item import TeamListResponse200Item
from .update_private_link_json_body import UpdatePrivateLinkJsonBody
from .user_info_by_id_response_200 import UserInfoByIdResponse200
from .user_info_by_id_response_200_experiences import UserInfoByIdResponse200Experiences
from .user_info_by_id_response_200_novel_user_experience_infos import (
    UserInfoByIdResponse200NovelUserExperienceInfos,
)
from .user_info_by_id_response_200_teams_item import UserInfoByIdResponse200TeamsItem
from .user_list_response_200_item import UserListResponse200Item
from .user_list_response_200_item_experiences import UserListResponse200ItemExperiences
from .user_list_response_200_item_novel_user_experience_infos import (
    UserListResponse200ItemNovelUserExperienceInfos,
)
from .user_list_response_200_item_teams_item import UserListResponse200ItemTeamsItem
from .user_logged_time_response_200 import UserLoggedTimeResponse200
from .user_logged_time_response_200_logged_time_item import (
    UserLoggedTimeResponse200LoggedTimeItem,
)
from .user_logged_time_response_200_logged_time_item_payment_interval import (
    UserLoggedTimeResponse200LoggedTimeItemPaymentInterval,
)

==> webknossos-0.12.3.tar.gz: webknossos-0.12.3/webknossos/client/_generated/models/__init__.py <==
""" Contains all the data models used in inputs/outputs """

from .action import Action
from .action_annotation_layer_parameters import ActionAnnotationLayerParameters
from .action_annotation_private_link_params import ActionAnnotationPrivateLinkParams
from .action_any_content import ActionAnyContent
from .action_cancel_upload_information import ActionCancelUploadInformation
from .action_js_value import ActionJsValue
from .action_list_object_id import ActionListObjectId
from .action_multipart_form_data_temporary_file import (
    ActionMultipartFormDataTemporaryFile,
)
from .action_reserve_upload_information import ActionReserveUploadInformation
from .action_upload_information import ActionUploadInformation
from .annotation_info_response_200 import AnnotationInfoResponse200
from .annotation_info_response_200_annotation_layers_item import (
    AnnotationInfoResponse200AnnotationLayersItem,
)
from .annotation_info_response_200_data_store import AnnotationInfoResponse200DataStore
from .annotation_info_response_200_owner import AnnotationInfoResponse200Owner
from .annotation_info_response_200_owner_teams_item import (
    AnnotationInfoResponse200OwnerTeamsItem,
)
from .annotation_info_response_200_restrictions import (
    AnnotationInfoResponse200Restrictions,
)
from .annotation_info_response_200_settings import AnnotationInfoResponse200Settings
from .annotation_info_response_200_settings_resolution_restrictions import (
    AnnotationInfoResponse200SettingsResolutionRestrictions,
)
from .annotation_info_response_200_stats import AnnotationInfoResponse200Stats
from .annotation_info_response_200_task import AnnotationInfoResponse200Task
from .annotation_info_response_200_task_needed_experience import (
    AnnotationInfoResponse200TaskNeededExperience,
)
from .annotation_info_response_200_task_status import (
    AnnotationInfoResponse200TaskStatus,
)
from .annotation_info_response_200_task_type import AnnotationInfoResponse200TaskType
from .annotation_info_response_200_task_type_settings import (
    AnnotationInfoResponse200TaskTypeSettings,
)
from .annotation_info_response_200_task_type_settings_resolution_restrictions import (
    AnnotationInfoResponse200TaskTypeSettingsResolutionRestrictions,
)
from .annotation_info_response_200_tracing_store import (
    AnnotationInfoResponse200TracingStore,
)
from .annotation_info_response_200_user import AnnotationInfoResponse200User
from .annotation_info_response_200_user_teams_item import (
    AnnotationInfoResponse200UserTeamsItem,
)
from .annotation_infos_by_task_id_response_200_item import (
    AnnotationInfosByTaskIdResponse200Item,
)
from .annotation_infos_by_task_id_response_200_item_annotation_layers_item import (
    AnnotationInfosByTaskIdResponse200ItemAnnotationLayersItem,
)
from .annotation_infos_by_task_id_response_200_item_data_store import (
    AnnotationInfosByTaskIdResponse200ItemDataStore,
)
from .annotation_infos_by_task_id_response_200_item_owner import (
    AnnotationInfosByTaskIdResponse200ItemOwner,
)
from .annotation_infos_by_task_id_response_200_item_owner_teams_item import (
    AnnotationInfosByTaskIdResponse200ItemOwnerTeamsItem,
)
from .annotation_infos_by_task_id_response_200_item_restrictions import (
    AnnotationInfosByTaskIdResponse200ItemRestrictions,
)
from .annotation_infos_by_task_id_response_200_item_settings import (
    AnnotationInfosByTaskIdResponse200ItemSettings,
)
from .annotation_infos_by_task_id_response_200_item_settings_resolution_restrictions import (
    AnnotationInfosByTaskIdResponse200ItemSettingsResolutionRestrictions,
)
from .annotation_infos_by_task_id_response_200_item_stats import (
    AnnotationInfosByTaskIdResponse200ItemStats,
)
from .annotation_infos_by_task_id_response_200_item_task import (
    AnnotationInfosByTaskIdResponse200ItemTask,
)
from .annotation_infos_by_task_id_response_200_item_task_needed_experience import (
    AnnotationInfosByTaskIdResponse200ItemTaskNeededExperience,
)
from .annotation_infos_by_task_id_response_200_item_task_status import (
    AnnotationInfosByTaskIdResponse200ItemTaskStatus,
)
from .annotation_infos_by_task_id_response_200_item_task_type import (
    AnnotationInfosByTaskIdResponse200ItemTaskType,
)
from .annotation_infos_by_task_id_response_200_item_task_type_settings import (
    AnnotationInfosByTaskIdResponse200ItemTaskTypeSettings,
)
from .annotation_infos_by_task_id_response_200_item_task_type_settings_resolution_restrictions import (
    AnnotationInfosByTaskIdResponse200ItemTaskTypeSettingsResolutionRestrictions,
)
from .annotation_infos_by_task_id_response_200_item_tracing_store import (
    AnnotationInfosByTaskIdResponse200ItemTracingStore,
)
from .annotation_infos_by_task_id_response_200_item_user import (
    AnnotationInfosByTaskIdResponse200ItemUser,
)
from .annotation_infos_by_task_id_response_200_item_user_teams_item import (
    AnnotationInfosByTaskIdResponse200ItemUserTeamsItem,
)
from .build_info_response_200 import BuildInfoResponse200
from .build_info_response_200_webknossos import BuildInfoResponse200Webknossos
from .build_info_response_200_webknossos_wrap import BuildInfoResponse200WebknossosWrap
from .create_private_link_json_body import CreatePrivateLinkJsonBody
from .create_project_json_body import CreateProjectJsonBody
from .current_user_info_response_200 import CurrentUserInfoResponse200
from .current_user_info_response_200_experiences import (
    CurrentUserInfoResponse200Experiences,
)
from .current_user_info_response_200_novel_user_experience_infos import (
    CurrentUserInfoResponse200NovelUserExperienceInfos,
)
from .current_user_info_response_200_teams_item import (
    CurrentUserInfoResponse200TeamsItem,
)
from .dataset_cancel_upload_json_body import DatasetCancelUploadJsonBody
from .dataset_finish_upload_json_body import DatasetFinishUploadJsonBody
from .dataset_info_response_200 import DatasetInfoResponse200
from .dataset_info_response_200_allowed_teams_cumulative_item import (
    DatasetInfoResponse200AllowedTeamsCumulativeItem,
)
from .dataset_info_response_200_allowed_teams_item import (
    DatasetInfoResponse200AllowedTeamsItem,
)
from .dataset_info_response_200_data_source import DatasetInfoResponse200DataSource
from .dataset_info_response_200_data_source_data_layers_item import (
    DatasetInfoResponse200DataSourceDataLayersItem,
)
from .dataset_info_response_200_data_source_data_layers_item_bounding_box import (
    DatasetInfoResponse200DataSourceDataLayersItemBoundingBox,
)
from .dataset_info_response_200_data_source_data_layers_item_default_view_configuration import (
    DatasetInfoResponse200DataSourceDataLayersItemDefaultViewConfiguration,
)
from .dataset_info_response_200_data_source_id import DatasetInfoResponse200DataSourceId
from .dataset_info_response_200_data_store import DatasetInfoResponse200DataStore
from .dataset_list_response_200_item import DatasetListResponse200Item
from .dataset_list_response_200_item_allowed_teams_cumulative_item import (
    DatasetListResponse200ItemAllowedTeamsCumulativeItem,
)
from .dataset_list_response_200_item_allowed_teams_item import (
    DatasetListResponse200ItemAllowedTeamsItem,
)
from .dataset_list_response_200_item_data_source import (
    DatasetListResponse200ItemDataSource,
)
from .dataset_list_response_200_item_data_source_id import (
    DatasetListResponse200ItemDataSourceId,
)
from .dataset_list_response_200_item_data_store import (
    DatasetListResponse200ItemDataStore,
)
from .dataset_reserve_upload_json_body import DatasetReserveUploadJsonBody
from .dataset_sharing_token_response_200 import DatasetSharingTokenResponse200
from .dataset_update_json_body import DatasetUpdateJsonBody
from .datastore_list_response_200_item import DatastoreListResponse200Item
from .folder_tree_response_200_item import FolderTreeResponse200Item
from .generate_token_for_data_store_response_200 import (
    GenerateTokenForDataStoreResponse200,
)
from .project_info_by_id_response_200 import ProjectInfoByIdResponse200
from .project_info_by_id_response_200_owner import ProjectInfoByIdResponse200Owner
from .project_info_by_id_response_200_owner_teams_item import (
    ProjectInfoByIdResponse200OwnerTeamsItem,
)
from .project_info_by_name_response_200 import ProjectInfoByNameResponse200
from .project_info_by_name_response_200_owner import ProjectInfoByNameResponse200Owner
from .project_info_by_name_response_200_owner_teams_item import (
    ProjectInfoByNameResponse200OwnerTeamsItem,
)
from .short_link_by_key_response_200 import ShortLinkByKeyResponse200
from .task_create_from_files_json_body import TaskCreateFromFilesJsonBody
from .task_info_response_200 import TaskInfoResponse200
from .task_info_response_200_needed_experience import (
    TaskInfoResponse200NeededExperience,
)
from .task_info_response_200_status import TaskInfoResponse200Status
from .task_info_response_200_type import TaskInfoResponse200Type
from .task_info_response_200_type_settings import TaskInfoResponse200TypeSettings
from .task_info_response_200_type_settings_resolution_restrictions import (
    TaskInfoResponse200TypeSettingsResolutionRestrictions,
)
from .task_infos_by_project_id_response_200_item import (
    TaskInfosByProjectIdResponse200Item,
)
from .task_infos_by_project_id_response_200_item_needed_experience import (
    TaskInfosByProjectIdResponse200ItemNeededExperience,
)
from .task_infos_by_project_id_response_200_item_status import (
    TaskInfosByProjectIdResponse200ItemStatus,
)
from .task_infos_by_project_id_response_200_item_type import (
    TaskInfosByProjectIdResponse200ItemType,
)
from .task_infos_by_project_id_response_200_item_type_settings import (
    TaskInfosByProjectIdResponse200ItemTypeSettings,
)
from .task_infos_by_project_id_response_200_item_type_settings_resolution_restrictions import (
    TaskInfosByProjectIdResponse200ItemTypeSettingsResolutionRestrictions,
)
from .team_list_response_200_item import TeamListResponse200Item
from .update_private_link_json_body import UpdatePrivateLinkJsonBody
from .user_info_by_id_response_200 import UserInfoByIdResponse200
from .user_info_by_id_response_200_experiences import UserInfoByIdResponse200Experiences
from .user_info_by_id_response_200_novel_user_experience_infos import (
    UserInfoByIdResponse200NovelUserExperienceInfos,
)
from .user_info_by_id_response_200_teams_item import UserInfoByIdResponse200TeamsItem
from .user_list_response_200_item import UserListResponse200Item
from .user_list_response_200_item_experiences import UserListResponse200ItemExperiences
from .user_list_response_200_item_novel_user_experience_infos import (
    UserListResponse200ItemNovelUserExperienceInfos,
)
from .user_list_response_200_item_teams_item import UserListResponse200ItemTeamsItem
from .user_logged_time_response_200 import UserLoggedTimeResponse200
from .user_logged_time_response_200_logged_time_item import (
    UserLoggedTimeResponse200LoggedTimeItem,
)
from .user_logged_time_response_200_logged_time_item_payment_interval import (
    UserLoggedTimeResponse200LoggedTimeItemPaymentInterval,
)

__all__ = (
    "Action",
    "ActionAnnotationLayerParameters",
    "ActionAnnotationPrivateLinkParams",
    "ActionAnyContent",
    "ActionCancelUploadInformation",
    "ActionJsValue",
    "ActionListObjectId",
    "ActionMultipartFormDataTemporaryFile",
    "ActionReserveUploadInformation",
    "ActionUploadInformation",
    "AnnotationInfoResponse200",
    "AnnotationInfoResponse200AnnotationLayersItem",
    "AnnotationInfoResponse200DataStore",
    "AnnotationInfoResponse200Owner",
    "AnnotationInfoResponse200OwnerTeamsItem",
    "AnnotationInfoResponse200Restrictions",
    "AnnotationInfoResponse200Settings",
    "AnnotationInfoResponse200SettingsResolutionRestrictions",
    "AnnotationInfoResponse200Stats",
    "AnnotationInfoResponse200Task",
    "AnnotationInfoResponse200TaskNeededExperience",
    "AnnotationInfoResponse200TaskStatus",
    "AnnotationInfoResponse200TaskType",
    "AnnotationInfoResponse200TaskTypeSettings",
    "AnnotationInfoResponse200TaskTypeSettingsResolutionRestrictions",
    "AnnotationInfoResponse200TracingStore",
    "AnnotationInfoResponse200User",
    "AnnotationInfoResponse200UserTeamsItem",
    "AnnotationInfosByTaskIdResponse200Item",
    "AnnotationInfosByTaskIdResponse200ItemAnnotationLayersItem",
    "AnnotationInfosByTaskIdResponse200ItemDataStore",
    "AnnotationInfosByTaskIdResponse200ItemOwner",
    "AnnotationInfosByTaskIdResponse200ItemOwnerTeamsItem",
    "AnnotationInfosByTaskIdResponse200ItemRestrictions",
    "AnnotationInfosByTaskIdResponse200ItemSettings",
    "AnnotationInfosByTaskIdResponse200ItemSettingsResolutionRestrictions",
    "AnnotationInfosByTaskIdResponse200ItemStats",
    "AnnotationInfosByTaskIdResponse200ItemTask",
    "AnnotationInfosByTaskIdResponse200ItemTaskNeededExperience",
    "AnnotationInfosByTaskIdResponse200ItemTaskStatus",
    "AnnotationInfosByTaskIdResponse200ItemTaskType",
    "AnnotationInfosByTaskIdResponse200ItemTaskTypeSettings",
    "AnnotationInfosByTaskIdResponse200ItemTaskTypeSettingsResolutionRestrictions",
    "AnnotationInfosByTaskIdResponse200ItemTracingStore",
    "AnnotationInfosByTaskIdResponse200ItemUser",
    "AnnotationInfosByTaskIdResponse200ItemUserTeamsItem",
    "BuildInfoResponse200",
    "BuildInfoResponse200Webknossos",
    "BuildInfoResponse200WebknossosWrap",
    "CreatePrivateLinkJsonBody",
    "CreateProjectJsonBody",
    "CurrentUserInfoResponse200",
    "CurrentUserInfoResponse200Experiences",
    "CurrentUserInfoResponse200NovelUserExperienceInfos",
    "CurrentUserInfoResponse200TeamsItem",
    "DatasetCancelUploadJsonBody",
    "DatasetFinishUploadJsonBody",
    "DatasetInfoResponse200",
    "DatasetInfoResponse200AllowedTeamsCumulativeItem",
    "DatasetInfoResponse200AllowedTeamsItem",
    "DatasetInfoResponse200DataSource",
    "DatasetInfoResponse200DataSourceDataLayersItem",
    "DatasetInfoResponse200DataSourceDataLayersItemBoundingBox",
    "DatasetInfoResponse200DataSourceDataLayersItemDefaultViewConfiguration",
    "DatasetInfoResponse200DataSourceId",
    "DatasetInfoResponse200DataStore",
    "DatasetListResponse200Item",
    "DatasetListResponse200ItemAllowedTeamsCumulativeItem",
    "DatasetListResponse200ItemAllowedTeamsItem",
    "DatasetListResponse200ItemDataSource",
    "DatasetListResponse200ItemDataSourceId",
    "DatasetListResponse200ItemDataStore",
    "DatasetReserveUploadJsonBody",
    "DatasetSharingTokenResponse200",
    "DatasetUpdateJsonBody",
    "DatastoreListResponse200Item",
    "FolderTreeResponse200Item",
    "GenerateTokenForDataStoreResponse200",
    "ProjectInfoByIdResponse200",
    "ProjectInfoByIdResponse200Owner",
    "ProjectInfoByIdResponse200OwnerTeamsItem",
    "ProjectInfoByNameResponse200",
    "ProjectInfoByNameResponse200Owner",
    "ProjectInfoByNameResponse200OwnerTeamsItem",
    "ShortLinkByKeyResponse200",
    "TaskCreateFromFilesJsonBody",
    "TaskInfoResponse200",
    "TaskInfoResponse200NeededExperience",
    "TaskInfoResponse200Status",
    "TaskInfoResponse200Type",
    "TaskInfoResponse200TypeSettings",
    "TaskInfoResponse200TypeSettingsResolutionRestrictions",
    "TaskInfosByProjectIdResponse200Item",
    "TaskInfosByProjectIdResponse200ItemNeededExperience",
    "TaskInfosByProjectIdResponse200ItemStatus",
    "TaskInfosByProjectIdResponse200ItemType",
    "TaskInfosByProjectIdResponse200ItemTypeSettings",
    "TaskInfosByProjectIdResponse200ItemTypeSettingsResolutionRestrictions",
    "TeamListResponse200Item",
    "UpdatePrivateLinkJsonBody",
    "UserInfoByIdResponse200",
    "UserInfoByIdResponse200Experiences",
    "UserInfoByIdResponse200NovelUserExperienceInfos",
    "UserInfoByIdResponse200TeamsItem",
    "UserListResponse200Item",
    "UserListResponse200ItemExperiences",
    "UserListResponse200ItemNovelUserExperienceInfos",
    "UserListResponse200ItemTeamsItem",
    "UserLoggedTimeResponse200",
    "UserLoggedTimeResponse200LoggedTimeItem",
    "UserLoggedTimeResponse200LoggedTimeItemPaymentInterval",
)
